/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.poi.ss.excelant;

import static org.junit.Assert.assertNotNull;

import org.apache.poi.ss.usermodel.Workbook;

public class MockExcelAntWorkbookHandler implements IExcelAntWorkbookHandler {
    public static boolean executed;
    public static Workbook workbook;
    
    
    @Override
    public void setWorkbook(Workbook workbook) {
        MockExcelAntWorkbookHandler.workbook = workbook;
    }

    @Override
    public void execute() {
        executed = true;
        assertNotNull(workbook);
    }
}
